@@ -15,7 +15,7 @@
  *                         and Technology (RIST).  All rights reserved.
  * Copyright (c) 2019      Mellanox Technologies, Inc.
  *                         All rights reserved.
- * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2023 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -66,9 +66,25 @@ BEGIN_C_DECLS
     "pmix.pnet.setapp" // (pmix_byte_object_t) blob containing info to be given to
                        //      pnet framework on remote nodes
 
+// define some bit handling macros
+#define PMIX_SET_BIT(a, f) \
+    (a) |= (f)
+
+#define PMIX_UNSET_BIT(a, f) \
+    (a) &= ~(f)
+
+#define PMIX_CHECK_BIT_IS_SET(a, f) \
+    ((a) & (f))
+
+#define PMIX_CHECK_BIT_NOT_SET(a, f) \
+    !PMIX_CHECK_BIT_IS_SET(a, f)
+
 #define PMIX_INFO_OP_COMPLETE       0x80000000
-#define PMIX_INFO_OP_COMPLETED(m)   ((pmix_info_t *) (m))->flags |= PMIX_INFO_OP_COMPLETE
-#define PMIX_INFO_OP_IS_COMPLETE(m) ((m)->flags & PMIX_INFO_OP_COMPLETE)
+#define PMIX_INFO_OP_COMPLETED(m) \
+      PMIX_SET_BIT((m)->flags, PMIX_INFO_OP_COMPLETE)
+#define PMIX_INFO_OP_IS_COMPLETE(m) \
+      PMIX_CHECK_BIT_IS_SET((m)->flags, PMIX_INFO_OP_COMPLETE)
+
 
 /* define an internal-only object for creating
  * lists of names */
@@ -88,6 +104,14 @@ typedef struct {
     char **description;
 } pmix_regattr_input_t;
 
+/* define a struct for holding entries in the
+ * dictionary of event strings */
+typedef struct {
+    uint32_t index;
+    char *name;
+    int32_t code;
+} pmix_event_string_t;
+
 /* define a struct for storing data in memory */
 typedef struct {
     uint32_t index;
@@ -414,6 +438,7 @@ typedef struct {
     pmix_object_t super;
     pmix_event_t ev;
     pmix_lock_t lock;
+    bool host_called;
     pmix_status_t status;
     pmix_query_t *queries;
     size_t nqueries;
@@ -437,6 +462,22 @@ typedef struct {
 } pmix_query_caddy_t;
 PMIX_CLASS_DECLARATION(pmix_query_caddy_t);
 
+typedef struct {
+    pmix_list_item_t super;
+    char *grpid;
+    pmix_proc_t *members;
+    size_t nmbrs;
+} pmix_group_t;
+PMIX_CLASS_DECLARATION(pmix_group_t);
+
+typedef struct {
+    pmix_list_item_t super;
+    pmix_group_t *grp;
+    pmix_rank_t rank;
+    size_t idx;
+} pmix_group_caddy_t;
+PMIX_CLASS_DECLARATION(pmix_group_caddy_t);
+
 typedef struct {
     pmix_list_item_t super;
     pmix_proc_t proc;
